#define MOZ_SOURCE_STAMP f6216ea8b8fc4ff0c22f95e0aae6c4df2a5e6b5f
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/f6216ea8b8fc4ff0c22f95e0aae6c4df2a5e6b5f
